import Http from './services/Http';
/**
 * Api class
 *
 * Base class to manage calls to API
 */
export default class Api {
    /**
     * The loading state of the service
     */
    loading: boolean;
    /**
     * Any error that was returned by the last call
     */
    error: any;
    /**
     * The Http service which makes the API call
     */
    http: Http;
    /**
     * The API constructor function
     *
     * @param   axios     An Axios instance
     */
    constructor(axios: any);
    /**
     * Use one of the built-in plugins
     *
     * @param   name      The name of the plugin
     * @param   params    Any options the plugin needs
     * @returns {this}
     */
    use(name: any, ...params: any[]): this;
    /**
     * Query the API via any HTTP method
     *
     * @param   method    The HTTP method to make the call
     * @param   path      The API path to call
     * @param   data      Any optional data to pass to the endpoints
     * @returns
     */
    request(method: string, path: string, data?: object): Promise<any>;
    /**
     * Call the API via HTTP GET
     *
     * @param   path      The API path to call
     * @param   data      Any optional data to pass to the endpoints
     * @returns
     */
    get(path: string, data?: object): Promise<any>;
    /**
     * Call the API via HTTP POST
     *
     * @param   path      The API path to call
     * @param   data      Any optional data to pass to the endpoints
     * @returns
     */
    post(path: string, data?: object): Promise<any>;
    /**
     * Add a callback to fire when any call completes successfully
     *
     * @param   callback
     * @returns
     */
    done(callback: any): this;
    /**
     * Add a callback to fire when any call fails to complete
     *
     * @param   callback
     * @returns
     */
    fail(callback: any): this;
}
