import { AxiosRequestConfig } from 'axios';
import ApiCore from './ApiCore';
import ActionMap from './services/ActionMap';
/**
 * Group class
 *
 * Manages related URLs of an API
 */
export default class ApiGroup extends ApiCore {
    /**
     * A map of API endpoints
     */
    actions: ActionMap;
    /**
     * Endpoint constructor
     *
     * @param   axios       An Axios instance
     * @param   actions     An optional hash of URLs
     */
    constructor(axios: any, actions?: any);
    /**
     * Add a new action
     *
     * @param   action    The name of the action to add
     * @param   config    An object conforming to the AxiosRequestConfig interface
     */
    add(action: string, config: AxiosRequestConfig): any;
    /**
     * Add a new action
     *
     * @param   action    The name of the action to add
     * @param   url       The url, and optionally method and url, of the API endpoint
     * @param   method    An optional HTTP method to use if the method is not declared in the url; then defaults to "get"
     * @param   callback? An optional handler function to fire on a successful call
     */
    add(action: string, url: string, method: string, callback?: Function): any;
    /**
     * Call a specific action
     *
     * @param   name      The name of the action to execute
     * @param   data      An optional hash of data to pass to the server
     * @returns {Promise<any>}
     */
    call(name: string, data?: any): Promise<any>;
    /**
     * Add a callback to fire when any call completes successfully
     *
     * @param   name      The name or names of actions to bind to
     * @param   callback  The function to fire
     * @returns this
     */
    when(name: string, callback: Function): this;
}
